==> devextreme-23.2.1-alpha-23255-1340.tgz: package/cjs/__internal/grids/tree_list/m_grid_view.js <==
/**
 * DevExtreme (cjs/__internal/grids/tree_list/m_grid_view.js)
 * Version: 23.2.0 (build 23255-1340)
 * Build date: Tue Sep 12 2023
 *
 * Copyright (c) 2012 - 2023 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _m_grid_view = require("../../grids/grid_core/views/m_grid_view");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
var ResizingController = _m_grid_view.gridViewModule.controllers.resizing.inherit({
    _getWidgetAriaLabel: () => "dxTreeList-ariaTreeList",
    _toggleBestFitMode(isBestFit) {
        this.callBase(isBestFit);
        var $rowsTable = this._rowsView.getTableElement();
        $rowsTable.find(".dx-treelist-cell-expandable").toggleClass(this.addWidgetPrefix("best-fit"), isBestFit)
    }
});
_m_core.default.registerModule("gridView", {
    defaultOptions: _m_grid_view.gridViewModule.defaultOptions,
    controllers: _extends(_extends({}, _m_grid_view.gridViewModule.controllers), {
        resizing: ResizingController
    }),
    views: _m_grid_view.gridViewModule.views
});

==> devextreme-24.2.1-alpha-24256-1935.tgz: package/cjs/__internal/grids/tree_list/m_grid_view.js <==
/**
 * DevExtreme (cjs/__internal/grids/tree_list/m_grid_view.js)
 * Version: 24.2.1-alpha-24256-1935
 * Build date: Thu Sep 12 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
var _m_grid_view = require("../../grids/grid_core/views/m_grid_view");
var _m_core = _interopRequireDefault(require("./m_core"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}
const TREELIST_EXPANDABLE_INSTRUCTION = "dxTreeList-ariaExpandableInstruction";
class TreeListResizingController extends _m_grid_view.ResizingController {
    constructor() {
        super(...arguments);
        this._expandableWidgetAriaId = TREELIST_EXPANDABLE_INSTRUCTION
    }
    _getWidgetAriaLabel() {
        return "dxTreeList-ariaTreeList"
    }
    _toggleBestFitMode(isBestFit) {
        super._toggleBestFitMode(isBestFit);
        const $rowsTable = this._rowsView.getTableElement();
        $rowsTable.find(".dx-treelist-cell-expandable").toggleClass(this.addWidgetPrefix("best-fit"), isBestFit)
    }
}
_m_core.default.registerModule("gridView", {
    defaultOptions: _m_grid_view.gridViewModule.defaultOptions,
    controllers: _extends({}, _m_grid_view.gridViewModule.controllers, {
        resizing: TreeListResizingController
    }),
    views: _m_grid_view.gridViewModule.views
});
